@@ -209,8 +209,14 @@ class MicroFetcher(object):
         response = requests.request("POST", url, headers=headers, data=payload)
 
         if response.status_code != 200:
+            self.app.logger.error(self.service_name)
             self.app.logger.error(response.text)
-            raise AppFetchServiceDataError()
+            custom_text = None
+            try:
+                custom_text = json.loads(response.text).get('message')
+            except json.decoder.JSONDecodeError:
+                pass
+            raise AppFetchServiceDataError(custom_text)
 
         result = response.json()
 
